<!DOCTYPE html>  
<html lang="en">  
  <head>  
    <meta charset="utf-8">  
    <title>Read later - ownCloud</title>  
  </head>
  <body>
  	<div class="message"><h1>Saved!</h1></div>
		<a href="javascript:self.close()" >Close the window</a>
  </body>  
</html>  